-------------------
--   Synthesis   --
-------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity ajout is
	generic (Kxa : real := 0.2;
			 Kxr : real := 0.02;
			 ktr : real := 0.02;
			 ktl : real := 0.02;
			 dARNm : real := 0.1;
			 dp : real := 0.1;
			 a : real := 0.0;
			 na : real := 2.0;
			 nr : real := 2.0);
	port (terminal Act_term : Act;
terminal rep_term : rep;

		  terminal Prot_term : araC);
end;

architecture conservative of ajout is

	constant valr_act : real := 100.0;
	constant valr_rep : real := 10.0;
	constant valc_arnm : real := 1.0;
 
	terminal ARNm_term : araC_arnm;

	quantity C_Act across Act_term to Act_cell;
quantity C_rep across rep_term to rep_cell;

	
	quantity CARNm across FARNm through ARNm_term to araC_arnm_cell;
	quantity Cprot across Fprot through Prot_term to araC_cell;
		
Begin

	r_Act : entity Act_resistor(conservative)
			 generic map (valr_act)
			 port map (a => Act_term, b => Act_cell);

	r_rep : entity rep_resistor(conservative)
			 generic map (valr_rep)
			 port map (a => rep_term, b => rep_cell);


			
	r_arnm : entity araC_arnm_resistor(conservative)
			 generic map (1.0/dARNm)
			 port map (a => ARNm_term, b => araC_arnm_cell);
			 
	c_arnm : entity araC_arnm_capacitor(conservative)
			 generic map (valc_arnm)
			 port map (a => ARNm_term, b => araC_arnm_cell);					   

			 
	r_prot : entity araC_resistor(conservative)
			 generic map (1.0/dp)
			 port map (a => Prot_term, b => araC_cell);

	
	FARNm == ktr*(a + 1.0/((1.0+(Kxa/(C_Act+1.0e-18))**na)*(1.0+(Kxr/(C_rep+1.0e-18))**(-nr))));

	
	Fprot == ktl*CARNm;
	
end conservative;

