-------------------
--   Synthesis   --
-------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity yemGFP_synth is
	generic (Kxa : real := 0.2;
			 Kxr : real := 0.02;
			 ktr : real := 0.1;
			 ktl : real := 0.1;
			 dARNm : real := 0.1;
			 dp : real := 0.1;
			 a : real := 0.0;
			 na : real := 2.0;
			 nr : real := 2.0);
	port (terminal araC_term : araC;
terminal lacI_term : lacI;

		  terminal Prot_term : yemGFP);
end;

architecture conservative of yemGFP_synth is

	constant valr_act : real := 100.0;
	constant valr_rep : real := 10.0;
	constant valc_arnm : real := 1.0;
 
	terminal ARNm_term : yemGFP_arnm;

	quantity C_araC across araC_term to araC_cell;
quantity C_lacI across lacI_term to lacI_cell;

	
	quantity CARNm across FARNm through ARNm_term to yemGFP_arnm_cell;
	quantity Cprot across Fprot through Prot_term to yemGFP_cell;
		
Begin

	r_araC : entity araC_resistor(conservative)
			 generic map (valr_act)
			 port map (a => araC_term, b => araC_cell);

	r_lacI : entity lacI_resistor(conservative)
			 generic map (valr_rep)
			 port map (a => lacI_term, b => lacI_cell);


			
	r_arnm : entity yemGFP_arnm_resistor(conservative)
			 generic map (1.0/dARNm)
			 port map (a => ARNm_term, b => yemGFP_arnm_cell);
			 
	c_arnm : entity yemGFP_arnm_capacitor(conservative)
			 generic map (valc_arnm)
			 port map (a => ARNm_term, b => yemGFP_arnm_cell);					   

			 
	r_prot : entity yemGFP_resistor(conservative)
			 generic map (1.0/dp)
			 port map (a => Prot_term, b => yemGFP_cell);

	
	FARNm == ktr*(a + 1.0/((1.0+(Kxa/(C_araC+1.0e-18))**na)*(1.0+(Kxr/(C_lacI+1.0e-18))**(-nr))));

	
	Fprot == ktl*CARNm;
	
end conservative;

